@@ -40,8 +40,9 @@ module asciiutils
  public :: enumerate,isdigit,split
  public :: get_column_labels
  public :: match_tag,match_taglist,append_number,make_tags_unique,get_value
+ public :: match_column
  public :: count_non_blank,find_repeated_tags,count_char
- public :: get_extensions
+ public :: get_extensions,readline_csv
 
  private
 
@@ -67,13 +68,14 @@ contains
 ! returns array of character strings (one per line)
 ! up to a maximum corresponding to the size of the array
 !---------------------------------------------------------------------------
-subroutine read_asciifile_char(filename,nlinesread,charline,ierror)
+subroutine read_asciifile_char(filename,nlinesread,charline,ierror,skip)
  character(len=*), intent(in) :: filename
  integer, intent(out) :: nlinesread
  character(len=*), dimension(:), intent(out) :: charline
  integer, intent(out), optional :: ierror
+ logical, intent(in), optional :: skip
  integer :: ierr,i,j,maxlines,iunit
- logical :: iexist
+ logical :: iexist,do_skip
  character(len=1) :: temp
 
  nlinesread = 0
@@ -99,12 +101,18 @@ subroutine read_asciifile_char(filename,nlinesread,charline,ierror)
  i = 0
  j = 1
  ierr = 0
+ do_skip = .false.
+ if (present(skip)) do_skip = skip
  over_lines: do while(j <= maxlines .and. ierr == 0)
     i = i + 1
     read(iunit,"(a)",iostat=ierr) charline(j)
     ! skip blank and comment lines
-    temp = adjustl(charline(j))
-    if (len_trim(charline(j)) > 0 .and. temp(1:1) /= '#') j = j + 1
+    if (do_skip) then
+       temp = adjustl(charline(j))
+       if (len_trim(charline(j)) > 0 .and. temp(1:1) /= '#') j = j + 1
+    else
+       j = j + 1
+    endif
  enddo over_lines
  nlinesread = j
 
@@ -381,13 +389,14 @@ end subroutine read_asciifile_real_string
 ! file must already be open and at the start
 ! slightly ad-hoc but its the best way I could think of!
 !---------------------------------------------------------------------------
-subroutine get_ncolumns(lunit,ncolumns,nheaderlines,maxheaderlines)
+subroutine get_ncolumns(lunit,ncolumns,nheaderlines,csv,maxheaderlines)
  integer, intent(in) :: lunit
  integer, intent(out) :: ncolumns,nheaderlines
  integer, intent(in), optional :: maxheaderlines
- integer :: ierr,ncolprev,ncolsthisline,maxlines
+ logical, intent(in), optional :: csv
+ integer :: ierr,ncolprev,ncolsthisline,maxlines,ncolstot
  character(len=5000) :: line
- logical :: nansinfile,infsinfile
+ logical :: nansinfile,infsinfile,is_csv
 
  if (present(maxheaderlines)) then
     maxlines = maxheaderlines
@@ -400,8 +409,11 @@ subroutine get_ncolumns(lunit,ncolumns,nheaderlines,maxheaderlines)
  ncolumns = 0
  ncolprev = -100
  ncolsthisline = 0
+ ncolstot = 0
  nansinfile = .false.
  infsinfile = .false.
+ is_csv = .false.
+ if (present(csv)) is_csv = csv
 !
 !--loop until we find two consecutive lines with the same number of columns (but non zero)
 !
@@ -414,7 +426,7 @@ subroutine get_ncolumns(lunit,ncolumns,nheaderlines,maxheaderlines)
     if (len_trim(line)==0) then
        ncolsthisline = -1
     else
-       if (ierr==0) ncolsthisline = ncolumnsline(line)
+       if (ierr==0) ncolsthisline = ncolumnsline(line,csv=is_csv,ntot=ncolstot)
        ncolumns = ncolsthisline
     endif
     nheaderlines = nheaderlines + 1
@@ -422,6 +434,8 @@ subroutine get_ncolumns(lunit,ncolumns,nheaderlines,maxheaderlines)
  enddo
  !--subtract 2 from the header line count (the last two lines which were the same)
  nheaderlines = max(nheaderlines - 2,0)
+ if (is_csv) ncolumns = ncolstot
+
  if (ierr  > 0 .or. ncolumns <= 0) then
     ncolumns = 0
  elseif (ierr  <  0) then
@@ -461,10 +475,24 @@ end subroutine get_nrows
 ! function returning the number of columns of real numbers from a given line
 !
 !---------------------------------------------------------------------------
-integer function ncolumnsline(line)
- character(len=*), intent(in) :: line
+integer function ncolumnsline(line,csv,ntot)
+ character(len=*), intent(in)   :: line
+ logical, intent(in),  optional :: csv
+ integer, intent(out), optional :: ntot
  real :: dummyreal(1000)
  integer :: ierr,i
+ logical :: use_commas
+
+ use_commas= .false.
+ if (present(csv)) use_commas = csv
+ if (use_commas) then
+    if (present(ntot)) then
+       ncolumnsline = ncolumnsline_csv(line,ntot)
+    else
+       ncolumnsline = ncolumnsline_csv(line)
+    endif
+    return
+ endif
 
  dummyreal = -666666.0
 
@@ -485,6 +513,67 @@ integer function ncolumnsline(line)
 
 end function ncolumnsline
 
+!---------------------------------------------------------------------------
+!
+! function returning the number of columns of real numbers from a given line
+!
+!---------------------------------------------------------------------------
+integer function ncolumnsline_csv(line,ntot) result(ncols)
+ character(len=*), intent(in) :: line
+ integer, parameter :: lenf = 15
+ character(len=lenf) :: fields(len(line)/lenf)
+ integer, intent(out), optional :: ntot
+ integer :: i,ierr,nfields
+ real :: dum
+
+ ! split line by commas
+ call split(line,',',fields,nfields)
+
+ ! report how many columns contain real numbers
+ ! or blank (non-text) entries
+ ncols = 0
+ do i=1,nfields
+    if (len_trim(fields(i))==0) then
+       ncols = ncols + 1
+    else
+       dum = -666666.
+       read(fields(i),*,iostat=ierr) dum
+       if (ierr==0) then
+          ncols = ncols + 1
+       endif
+    endif
+ enddo
+
+ if (present(ntot)) ntot = nfields
+
+end function ncolumnsline_csv
+
+!---------------------------------------------------------------------------
+!
+! read a line from a csv file and parse for real numbers
+!
+!---------------------------------------------------------------------------
+subroutine readline_csv(line,ncols,datcol)
+ character(len=*), intent(in) :: line
+ integer, intent(in)  :: ncols
+ real,    intent(out) :: datcol(ncols)
+ integer, parameter :: lenf = 15
+ character(len=lenf) :: fields(ncols)
+ !logical, intent(in)  :: mask(ncols)
+ integer :: nfields,i,icol,ierr
+
+ ! split line by commas
+ call split(line,',',fields,nfields)
+
+ ! read only columns that contain real numbers
+ icol = 0
+ do i=1,min(nfields,ncols)
+    icol = icol + 1
+    read(fields(i),*,iostat=ierr) datcol(icol)
+ enddo
+
+end subroutine readline_csv
+
 !----------------------------------------------------------------------
 !
 ! Small utility to return the number of comment lines in an ascii
@@ -843,14 +932,17 @@ end function enumerate
 pure subroutine split(string,delim,stringarr,nsplit)
  character(len=*), intent(in)  :: string
  character(len=*), intent(in)  :: delim
- character(len=*), intent(out), dimension(:) :: stringarr
+ character(len=*), intent(out), dimension(:), optional :: stringarr
  integer,          intent(out) :: nsplit
- integer :: i,j,imax,iend
+ integer :: i,j,imax,iend,nmax
 
  i = 1
  nsplit = 0
  imax = len(string)
- do while(nsplit < size(stringarr) .and. i <= imax)
+ nmax = imax
+ if (present(stringarr)) nmax = size(stringarr)
+
+ do while(nsplit < nmax .and. i <= imax)
     ! find next non-blank character
     if (string(i:i)==' ') then
        do while (string(i:i)==' ')
@@ -868,7 +960,7 @@ pure subroutine split(string,delim,stringarr,nsplit)
     iend = min(i+j-1,imax)
     ! extract the substring
     nsplit = nsplit + 1
-    if (nsplit <= size(stringarr)) then
+    if (nsplit <= nmax .and. present(stringarr)) then
        stringarr(nsplit) = string(i:iend)
     endif
     i = iend + len(delim) + 1
@@ -881,20 +973,24 @@ end subroutine split
 ! extract a list of labels from the header line of a file
 !
 !---------------------------------------------------------------------------
-subroutine get_column_labels(line,nlabels,labels,method,ndesired)
+subroutine get_column_labels(line,nlabels,labels,method,ndesired,csv)
  character(len=*), intent(in)  :: line
  integer,          intent(out) :: nlabels
  character(len=*), dimension(:), intent(out) :: labels
  integer,          intent(out), optional :: method
  integer,          intent(in),  optional :: ndesired
+ logical,          intent(in),  optional :: csv
  integer :: i1,i2,i,nlabelstmp,nlabels_prev,istyle,ntarget
  character(len=1) :: leadingchar
  character(len=4), parameter :: spaces = '    '
+ logical :: is_csv
 
  nlabels = 0
  i1 = 1
  istyle = 0
  ntarget = -1
+ is_csv = .false.
+ if (present(csv)) is_csv = csv
  if (present(ndesired)) ntarget = ndesired
  !
  ! strip leading comment character ('#')
@@ -907,7 +1003,7 @@ subroutine get_column_labels(line,nlabels,labels,method,ndesired)
  i1 = max(i1,index(line,'=')+1)
  i2 = i1
 
- if (index(nospaces(line),'][') > 0) then
+ if (index(nospaces(line),'][') > 0 .and. .not.is_csv) then
     !
     ! format style 1: # [ mylabel1 ] [ mylabel2 ] [ mylabel3 ]
     !
@@ -918,13 +1014,17 @@ subroutine get_column_labels(line,nlabels,labels,method,ndesired)
        call split(line(i1:),']'//spaces(1:i)//'[',labels,nlabels)
        if (nlabels > 1) exit over_spaces1
     enddo over_spaces1
- elseif (index(line,',') > 1) then
+ elseif (index(line,',') > 1 .or. is_csv) then
     !
     ! format style 2: mylabel1,mylabel2,mylabel3
     !
     istyle = 2
     call split(line(i1:),',',labels,nlabelstmp)
-    nlabels = count_sensible_labels(nlabelstmp,labels)
+    if (is_csv) then
+       nlabels = nlabelstmp  ! allow blank/arbitrary labels in csv format
+    else
+       nlabels = count_sensible_labels(nlabelstmp,labels)
+    endif
  else
     !
     ! format style 3: #     mylabel1     mylabel2     mylabel3
@@ -1062,6 +1162,25 @@ integer function match_tag(tags,tag)
 
 end function match_tag
 
+!------------------------------------------
+! match tag against a list of tags
+! or by giving the column number explicitly
+! returns index of matching tag in the list
+!------------------------------------------
+integer function match_column(tags,tag)
+ character(len=*), intent(in) :: tags(:)
+ character(len=*), intent(in) :: tag
+ integer :: ierr
+
+ ! try to match the string tag first
+ match_column = match_tag(tags,tag)
+ if (match_column == 0) then
+    ! try to read it as an integer from the string
+    read(tag,*,iostat=ierr) match_column
+ endif
+
+end function match_column
+
 !----------------------------------------------
 ! match tag against a list of tags
 ! and extract the value from an array of reals
